@@ -1,9 +1,11 @@
 package Mojo::DOM::Role::Analyzer ;
-$Mojo::DOM::Role::Analyzer::VERSION = '0.014';
+$Mojo::DOM::Role::Analyzer::VERSION = '0.015';
 use strict;
 use warnings;
 use Role::Tiny;
 use Carp;
+#use Log::Log4perl::Shortcuts qw(:all);
+
 
 use overload "cmp" => sub { $_[0]->compare(@_) }, fallback => 1;
 
@@ -216,9 +218,28 @@ sub tag_analysis {
     push @sub_enclosing_nodes, @enclosing_nodes;
   }
 
+  # cleanup
   @sub_enclosing_nodes = sort { $a->{selector} cmp $b->{selector} } @sub_enclosing_nodes;
+  my $last_node;
+  my @filtered_enclosing_nodes;
+  foreach my $sen (@sub_enclosing_nodes) {
+    if (!$last_node) {
+      $last_node = $sen;
+      next;
+    }
 
-  return @sub_enclosing_nodes;
+    if ($s->at($last_node->{selector})->is_ancestor_to($s->at($sen->{selector}))) {
+      if ($last_node->{size} != $sen->{size} || $last_node->{direct_children} != $sen->{direct_children}) {
+        push @filtered_enclosing_nodes, $last_node;
+      }
+    } else {
+      push @filtered_enclosing_nodes, $last_node;
+    }
+    $last_node = $sen;
+  }
+  push @filtered_enclosing_nodes, $last_node;
+
+  return @filtered_enclosing_nodes;
 
 }
 
@@ -239,25 +260,27 @@ sub _gsec {
 
     $props{classes} = $classes;
     $props{direct_children} = $s->children($selector)->size;;
-    $props{avg_tag_depth} = ($depth_total / $props{size});
+    my $avg_depth = sprintf('%.3f', ($depth_total / $props{size}));
+    $avg_depth =~ s/\.0+$//g;
+    $props{avg_tag_depth} = $avg_depth;
     $props{all_tags_have_same_depth} = $same_depth;
     push @sub_enclosing_nodes, \%props;
   }
 
-
   foreach my $c ($s->children->each) {
     next if $c->tag eq $selector;
     my $size = $c->find($selector)->size;
     next unless $size;
 
     my $cdn_with_sel = $c->children($selector)->size;
-
     my ($depth_total, $same_depth, $classes) = $c->_calc_depth($selector);
 
+    my $avg_depth = sprintf('%.3f', ($depth_total / $size));
+    $avg_depth =~ s/\.0+$//g;
     push @sub_enclosing_nodes,  { selector => $c->selector,
                                   size => $size,
                                   classes => $classes,
-                                  avg_tag_depth => ($depth_total / $size),
+                                  avg_tag_depth => $avg_depth,
                                   all_tags_have_same_depth => $same_depth,
                                   direct_children => $cdn_with_sel,
                                 };
@@ -512,7 +535,7 @@ with the following information for each of the enclosing nodes:
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
